@@ -23,8 +23,7 @@ class VersionTester(unittest.TestCase):
     def setUp(self):
         """setup the test settings with environment variables
         """
-        
-        # -----------------------------------------------------------------
+       # -----------------------------------------------------------------
         # start of the setUp
         # create the environment variable and point it to a temp directory
         self.temp_config_folder = tempfile.mkdtemp()
@@ -67,17 +66,18 @@ class VersionTester(unittest.TestCase):
             "version_number": 1,
             "note": "this is the note for this version",
             "created_by": self.test_user,
-            "extension": ".ma"
+            "extension": ".ma",
+            "is_published": False
         }
         
         self.test_version = Version(**self.kwargs)
         
         self._name_test_values = [
             ("base name", "Base_Name"),
-            ("123123 base_name", "Base_Name"),
-            ("123432!+!'^+Base_NAme323^+'^%&+%&324", "Base_NAme323324"),
+            ("123123 base_name", "123123_Base_Name"),
+            ("123432!+!'^+Base_NAme323^+'^%&+%&324", "123432Base_NAme323324"),
             ("    ---base 9s_name", "Base_9s_Name"),
-            ("    ---base 9s-name", "Base_9s_Name"),
+            ("    ---base 9s-name", "Base_9s-Name"),
             (" multiple     spaces are    converted to under     scores",
              "Multiple_Spaces_Are_Converted_To_Under_Scores"),
             ("camelCase", "CamelCase"),
@@ -89,11 +89,12 @@ class VersionTester(unittest.TestCase):
             ("baseName", "BaseName"),
             (" baseName", "BaseName"),
             (" base name", "Base_Name"),
-            (" 12base name", "Base_Name"),
-            (" 12 base name", "Base_Name"),
-            (" 12 base name 13", "Base_Name_13"),
-            (">£#>$#£½$ 12 base £#$£#$£½¾{½{ name 13", "Base_Name_13"),
+            (" 12base name", "12base_Name"),
+            (" 12 base name", "12_Base_Name"),
+            (" 12 base name 13", "12_Base_Name_13"),
+            (">£#>$#£½$ 12 base £#$£#$£½¾{½{ name 13", "12_Base_Name_13"),
             ("_base_name_", "Base_Name"),
+            ("Dash-Characters-Are-Preserved", "Dash-Characters-Are-Preserved")
         ]
     
     def tearDown(self):
@@ -270,7 +271,7 @@ class VersionTester(unittest.TestCase):
         """testing if the base_name attribute is formatted correctly when it is
         set to a value
         """
-        for test_value in self._name_test_values:
+        for i, test_value in enumerate(self._name_test_values):
             self.test_version.base_name = test_value[0]
             self.assertEqual(self.test_version.base_name, test_value[1])
     
@@ -278,7 +279,7 @@ class VersionTester(unittest.TestCase):
         """testing if a ValueError will be raised when the base_name argument
         is an empty string after it is formatted
         """
-        self.kwargs["base_name"] = "'^+'^23423"
+        self.kwargs["base_name"] = "'^+'^#@#$"
         self.assertRaises(ValueError, Version, **self.kwargs)
     
     def test_base_name_attribute_is_empty_string_after_formatting(self):
@@ -286,7 +287,7 @@ class VersionTester(unittest.TestCase):
         is an empty string after it is formatted
         """
         self.assertRaises(ValueError, setattr, self.test_version, "base_name",
-                          "'^+'^23423")
+                          "'^+'^#@$#")
 
     def test_take_name_argument_is_skipped(self):
         """testing if the default value MAIN is used when the take_name
@@ -359,7 +360,7 @@ class VersionTester(unittest.TestCase):
         """testing if a ValueError will be raised when the take_name argument
         is an empty string after it is formatted
         """
-        self.kwargs["take_name"] = "'^+'^23423"
+        self.kwargs["take_name"] = "'^+'^"
         self.assertRaises(ValueError, Version, **self.kwargs)
     
     def test_take_name_attribute_is_empty_string_after_formatting(self):
@@ -367,7 +368,7 @@ class VersionTester(unittest.TestCase):
         is an empty string after it is formatted
         """
         self.assertRaises(ValueError, setattr, self.test_version, "take_name",
-                          "'^+'^23423")
+                          "'^+'^")
     
     def test_version_number_argument_is_skipped_for_new_Version(self):
         """testing if the default value is used for the version attribute if
@@ -468,18 +469,20 @@ class VersionTester(unittest.TestCase):
         self.assertEqual(new_vers1.version_number, 1)
         self.assertEqual(new_vers1.version_number, 1)
 
-    def test_max_version_returns_the_maximum_version_number_from_the_database_for_changing_types(self):
-        """testing if the max_version is returning the maximum version number
-        for the current Version from the database for changing type values
-        """
-        self.fail("test is not implemented yet")
-    
-    def test_max_version_returns_the_maximum_version_number_from_the_database_for_changing_version_ofs(self):
-        """testing if the max_version is returning the maximum version number
-        for the current Version from the database for changing version_of
-        values
-        """
-        self.fail("test is not implemented yet")
+    # TODO: update this test
+#    def test_max_version_returns_the_maximum_version_number_from_the_database_for_changing_types(self):
+#        """testing if the max_version is returning the maximum version number
+#        for the current Version from the database for changing type values
+#        """
+#        self.fail("test is not implemented yet")
+
+    # TODO: update this test
+#    def test_max_version_returns_the_maximum_version_number_from_the_database_for_changing_version_ofs(self):
+#        """testing if the max_version is returning the maximum version number
+#        for the current Version from the database for changing version_of
+#        values
+#        """
+#        self.fail("test is not implemented yet")
     
     def test_max_version_returns_the_maximum_version_number_from_the_database_for_changing_take_names(self):
         """testing if the max_version is returning the maximum version number
@@ -1195,8 +1198,8 @@ class VersionTester(unittest.TestCase):
     
     def test_dependency_update_list_method_returns_a_list_of_Versions_that_needs_update(self):
         """testing if the dependency_update_list returns a list of Version
-        instances which are referenced by this Version instance but have newer
-        versions available
+        instances which are referenced by this Version instance but have a
+        newer published versions available
         """
         
         # create a couple of Versions
@@ -1204,37 +1207,64 @@ class VersionTester(unittest.TestCase):
         # Group 1
         self.kwargs["take_name"] = "Take1"
         versionRef_A1 = Version(**self.kwargs)
-        versionRef_A1.save()
+        versionRef_A1.is_published = True
+        versionRef_A1.save() 
+        
         versionRef_A2 = Version(**self.kwargs)
+        versionRef_A2.is_published = False
         versionRef_A2.save()
+        
         versionRef_A3 = Version(**self.kwargs)
+        versionRef_A3.is_published = True
         versionRef_A3.save()
         
+        versionRef_A4 = Version(**self.kwargs)
+        versionRef_A4.is_published = False
+        versionRef_A4.save()
+        
         # Group 2
         # just change the take
         self.kwargs["take_name"] = "Take2"
         versionRef_B1 = Version(**self.kwargs)
+        versionRef_B1.is_published = True
         versionRef_B1.save()
+        
         versionRef_B2 = Version(**self.kwargs)
+        versionRef_B2.is_published = False
         versionRef_B2.save()
+        
         versionRef_B3 = Version(**self.kwargs)
+        versionRef_B3.is_published = True
         versionRef_B3.save()
-
+        
+        versionRef_B4 = Version(**self.kwargs)
+        versionRef_B4.is_published = False
+        versionRef_B4.save()
+        
         # Group 3
         # just change the take
         self.kwargs["take_name"] = "Take3"
         versionRef_C1 = Version(**self.kwargs)
+        versionRef_C1.is_published = True
         versionRef_C1.save()
+        
         versionRef_C2 = Version(**self.kwargs)
+        versionRef_C2.is_published = False
         versionRef_C2.save()
+        
         versionRef_C3 = Version(**self.kwargs)
+        versionRef_C3.is_published = True
         versionRef_C3.save()
         
+        versionRef_C4 = Version(**self.kwargs)
+        versionRef_C4.is_published = False
+        versionRef_C4.save()
+        
         # Main Version
         self.kwargs["take_name"] = "Take4"
         versionMain = Version(**self.kwargs)
         versionMain.save()
-
+        
         # and reference them to each other
         versionMain.references.append(versionRef_A1)
         versionMain.references.append(versionRef_B1)
@@ -1247,63 +1277,219 @@ class VersionTester(unittest.TestCase):
         # and versionRef_A1 and versionRef_B1 are the ones in the list
         self.assertTrue(versionRef_A1 in versionMain.dependency_update_list)
         self.assertTrue(versionRef_B1 in versionMain.dependency_update_list)
+       
+    
+        
+    #def test_dependency_update_list_method_returns_a_list_of_Versions_that_needs_update(self):
+    #    """testing if the dependency_update_list returns a list of Version
+    #    instances which are referenced by this Version instance but have newer
+    #    versions available
+    #    """
+    #    
+    #    # create a couple of Versions
+    #    
+    #    # Group 1
+    #    self.kwargs["take_name"] = "Take1"
+    #    versionRef_A1 = Version(**self.kwargs)
+    #    versionRef_A1.save()
+    #    versionRef_A2 = Version(**self.kwargs)
+    #    versionRef_A2.save()
+    #    versionRef_A3 = Version(**self.kwargs)
+    #    versionRef_A3.save()
+    #    
+    #    # Group 2
+    #    # just change the take
+    #    self.kwargs["take_name"] = "Take2"
+    #    versionRef_B1 = Version(**self.kwargs)
+    #    versionRef_B1.save()
+    #    versionRef_B2 = Version(**self.kwargs)
+    #    versionRef_B2.save()
+    #    versionRef_B3 = Version(**self.kwargs)
+    #    versionRef_B3.save()
 
-    def test_dependency_update_list_method_returns_a_list_of_Versions_that_needs_update_for_deeper_references(self):
-        """testing if the dependency_update_list returns a list of Version
-        instances which are referenced by this Version instance but have newer
-        versions available and also return their references if they also have
-        newer versions
+    #    # Group 3
+    #    # just change the take
+    #    self.kwargs["take_name"] = "Take3"
+    #    versionRef_C1 = Version(**self.kwargs)
+    #    versionRef_C1.save()
+    #    versionRef_C2 = Version(**self.kwargs)
+    #    versionRef_C2.save()
+    #    versionRef_C3 = Version(**self.kwargs)
+    #    versionRef_C3.save()
+    #    
+    #    # Main Version
+    #    self.kwargs["take_name"] = "Take4"
+    #    versionMain = Version(**self.kwargs)
+    #    versionMain.save()
+
+    #    # and reference them to each other
+    #    versionMain.references.append(versionRef_A1)
+    #    versionMain.references.append(versionRef_B1)
+    #    versionMain.references.append(versionRef_C3)
+    #    versionMain.save()
+    #    
+    #    # check if the dependency_update_list has only two elements
+    #    self.assertEqual(len(versionMain.dependency_update_list), 2)
+    #    
+    #    # and versionRef_A1 and versionRef_B1 are the ones in the list
+    #    self.assertTrue(versionRef_A1 in versionMain.dependency_update_list)
+    #    self.assertTrue(versionRef_B1 in versionMain.dependency_update_list)
+
+    #def test_dependency_update_list_method_returns_a_list_of_Versions_that_needs_update_for_deeper_references(self):
+    #    """testing if the dependency_update_list returns a list of Version
+    #    instances which are referenced by this Version instance but have newer
+    #    versions available and also return their references if they also have
+    #    newer versions
+    #    """
+
+    #    # create a couple of Versions
+
+    #    # Group 1
+    #    self.kwargs["take_name"] = "Take1"
+    #    versionRef_A1 = Version(**self.kwargs)
+    #    versionRef_A1.save()
+    #    versionRef_A2 = Version(**self.kwargs)
+    #    versionRef_A2.save()
+    #    versionRef_A3 = Version(**self.kwargs)
+    #    versionRef_A3.save()
+
+    #    # Group 2
+    #    # just change the take
+    #    self.kwargs["take_name"] = "Take2"
+    #    versionRef_B1 = Version(**self.kwargs)
+    #    versionRef_B1.save()
+    #    versionRef_B2 = Version(**self.kwargs)
+    #    versionRef_B2.save()
+    #    versionRef_B3 = Version(**self.kwargs)
+    #    versionRef_B3.save()
+
+    #    # Group 3
+    #    # just change the take
+    #    self.kwargs["take_name"] = "Take3"
+    #    versionRef_C1 = Version(**self.kwargs)
+    #    versionRef_C1.save()
+    #    versionRef_C2 = Version(**self.kwargs)
+    #    versionRef_C2.save()
+    #    versionRef_C3 = Version(**self.kwargs)
+    #    versionRef_C3.save()
+
+    #    # Main Version
+    #    self.kwargs["take_name"] = "Take4"
+    #    versionMain = Version(**self.kwargs)
+    #    versionMain.save()
+
+    #    # and reference them to each other
+    #    versionMain.references.append(versionRef_A1)
+    #    versionRef_A1.references.append(versionRef_B1)
+    #    versionRef_B1.references.append(versionRef_C1)
+    #    versionMain.save()
+    #    versionRef_A1.save()
+    #    versionRef_B1.save()
+
+    #    # check if the dependency_update_list has only two elements
+    #    self.assertEqual(len(versionMain.dependency_update_list), 3)
+
+    #    # and versionRef_A1 and versionRef_B1 are the ones in the list
+    #    self.assertTrue(versionRef_A1 in versionMain.dependency_update_list)
+    #    self.assertTrue(versionRef_B1 in versionMain.dependency_update_list)
+    #    self.assertTrue(versionRef_C1 in versionMain.dependency_update_list)
+    
+    def test_is_published_argument_is_skipped(self):
+        """testing if the ipublished attribute will be false when the
+        is_published argument is skipped
+        """
+        
+        self.kwargs.pop("is_published")
+        new_version = Version(**self.kwargs)
+        self.assertEqual(new_version.is_published, False)
+    
+    def test_is_published_argument_is_working_properly(self):
+        """testing if the is_published argument is properly set the
+        is_published attribute
+        """
+        self.kwargs["is_published"] = True
+        new_version = Version(**self.kwargs)
+        self.assertEqual(new_version.is_published, True)
+    
+    def test_is_published_attribute_is_working_properly(self):
+        """testing if the is_published attribute is working properly
+        """
+        self.test_version.is_published = True
+        self.assertEqual(self.test_version.is_published, True)
+    
+    def test_latest_published_version_is_working_properly(self):
+        """testing if the latest_published_version is returning the latest
+        published version properlyy
+        """
+        
+        vers1 = self.test_version
+        
+        self.kwargs["is_published"] = True
+        vers2 = Version(**self.kwargs)
+        vers2.save()
+
+        self.kwargs["is_published"] = False
+        vers3 = Version(**self.kwargs)
+        vers3.save()
+
+        self.kwargs["is_published"] = False
+        vers4 = Version(**self.kwargs)
+        vers4.save()
+
+        self.kwargs["is_published"] = True
+        vers5 = Version(**self.kwargs)
+        vers5.save()
+
+        self.kwargs["is_published"] = False
+        vers6 = Version(**self.kwargs)
+        vers6.save()
+
+        self.kwargs["is_published"] = False
+        vers7 = Version(**self.kwargs)
+        vers7.save()
+        
+        self.assertEqual(vers1.latest_published_version(), vers5)
+        self.assertEqual(vers2.latest_published_version(), vers5)
+        self.assertEqual(vers3.latest_published_version(), vers5)
+        self.assertEqual(vers4.latest_published_version(), vers5)
+        self.assertEqual(vers5.latest_published_version(), vers5)
+        self.assertEqual(vers6.latest_published_version(), vers5)
+        self.assertEqual(vers7.latest_published_version(), vers5)
+
+    def test_is_latest_published_version_works_properly(self):
+        """testing if the is_latest_published_version is working properly
         """
 
-        # create a couple of Versions
-
-        # Group 1
-        self.kwargs["take_name"] = "Take1"
-        versionRef_A1 = Version(**self.kwargs)
-        versionRef_A1.save()
-        versionRef_A2 = Version(**self.kwargs)
-        versionRef_A2.save()
-        versionRef_A3 = Version(**self.kwargs)
-        versionRef_A3.save()
-
-        # Group 2
-        # just change the take
-        self.kwargs["take_name"] = "Take2"
-        versionRef_B1 = Version(**self.kwargs)
-        versionRef_B1.save()
-        versionRef_B2 = Version(**self.kwargs)
-        versionRef_B2.save()
-        versionRef_B3 = Version(**self.kwargs)
-        versionRef_B3.save()
-
-        # Group 3
-        # just change the take
-        self.kwargs["take_name"] = "Take3"
-        versionRef_C1 = Version(**self.kwargs)
-        versionRef_C1.save()
-        versionRef_C2 = Version(**self.kwargs)
-        versionRef_C2.save()
-        versionRef_C3 = Version(**self.kwargs)
-        versionRef_C3.save()
-
-        # Main Version
-        self.kwargs["take_name"] = "Take4"
-        versionMain = Version(**self.kwargs)
-        versionMain.save()
-
-        # and reference them to each other
-        versionMain.references.append(versionRef_A1)
-        versionRef_A1.references.append(versionRef_B1)
-        versionRef_B1.references.append(versionRef_C1)
-        versionMain.save()
-        versionRef_A1.save()
-        versionRef_B1.save()
-
-        # check if the dependency_update_list has only two elements
-        self.assertEqual(len(versionMain.dependency_update_list), 3)
-
-        # and versionRef_A1 and versionRef_B1 are the ones in the list
-        self.assertTrue(versionRef_A1 in versionMain.dependency_update_list)
-        self.assertTrue(versionRef_B1 in versionMain.dependency_update_list)
-        self.assertTrue(versionRef_C1 in versionMain.dependency_update_list)
+        vers1 = self.test_version
 
+        self.kwargs["is_published"] = True
+        vers2 = Version(**self.kwargs)
+        vers2.save()
+    
+        self.kwargs["is_published"] = False
+        vers3 = Version(**self.kwargs)
+        vers3.save()
+    
+        self.kwargs["is_published"] = False
+        vers4 = Version(**self.kwargs)
+        vers4.save()
+    
+        self.kwargs["is_published"] = True
+        vers5 = Version(**self.kwargs)
+        vers5.save()
+    
+        self.kwargs["is_published"] = False
+        vers6 = Version(**self.kwargs)
+        vers6.save()
+    
+        self.kwargs["is_published"] = False
+        vers7 = Version(**self.kwargs)
+        vers7.save()
+        
+        self.assertEqual(vers1.is_latest_published_version(), False)
+        self.assertEqual(vers2.is_latest_published_version(), False)
+        self.assertEqual(vers3.is_latest_published_version(), False)
+        self.assertEqual(vers4.is_latest_published_version(), False)
+        self.assertEqual(vers5.is_latest_published_version(), True)
+        self.assertEqual(vers6.is_latest_published_version(), False)
+        self.assertEqual(vers7.is_latest_published_version(), False)
